@@ -834,3 +834,16 @@ def st_check_missings_by_campaigns(app, campaigns):
         )
         db.session.commit()
     return (st_cbc_1.id, st_cbc_2.id)
+
+
+@pytest.fixture
+def st_check_outliers_by_campaigns(app, campaigns):
+    with OpenBar():
+        st_cbc_1 = scheduled_tasks.ST_CheckOutliersByCampaign.new(
+            campaign_id=campaigns[0]
+        )
+        st_cbc_2 = scheduled_tasks.ST_CheckOutliersByCampaign.new(
+            campaign_id=campaigns[1]
+        )
+        db.session.commit()
+    return (st_cbc_1.id, st_cbc_2.id)
